@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = "2.023";
+our $VERSION = "2.024";
 # ABSTRACT: time tracking for impatient and lazy command line lovers
 
 use App::TimeTracker::Data::Task;
@@ -273,6 +273,7 @@ sub project_tree {
             }
         }
     }
+
     return \%tree;
 }
 
@@ -306,7 +307,7 @@ App::TimeTracker - time tracking for impatient and lazy command line lovers
 
 =head1 VERSION
 
-version 2.023
+version 2.024
 
 =head1 SYNOPSIS
 
@@ -316,7 +317,8 @@ Backend for the C<tracker> command. See L<tracker> and/or C<perldoc tracker> for
 
 Maros Kollar, Klaus Ita, Yanick Champoux, Lukas Rampa, David Schmidt,
 Michael Kröll, Thomas Sibley, Nelo Onyiah, Jozef Kutej, Roland Lammel,
-Ruslan Zakirov, Kartik Thakore, Tokuhiro Matsuno, Paul Cochrane, David Provost
+Ruslan Zakirov, Kartik Thakore, Tokuhiro Matsuno, Paul Cochrane, David Provost,
+Mohammad S Anwar
 
 =head1 AUTHOR
 
