@@ -188,10 +188,10 @@ sub get_detail {
     my ( $self, $level ) = @_;
 
     my $detail = {};
-    if ( $level eq 'tag' || $level eq 'all' ) {
+    if ( $level eq 'tag' || $level eq 'description' ) {
         $detail->{tags} = $self->tags;
     }
-    if ( $level eq 'description' || $level eq 'all' ) {
+    if ( $level eq 'description' ) {
         $detail->{desc} = $self->description;
     }
     return $detail;
@@ -212,7 +212,7 @@ App::TimeTracker::Data::Task - App::TimeTracker Task storage
 
 =head1 VERSION
 
-version 2.023
+version 2.024
 
 =head1 DESCRIPTION
 
